/* nut.h */

/*
    NUT nutrition software 
    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#define PROCNT 0
#define FAT 1
#define CHOCDF 2
#define ASH 3
#define ENERC_KCAL 4
#define STARCH 5
#define SUCS 6
#define GLUS 7
#define FRUS 8
#define LACS 9
#define MALS 10
#define ALC 11
#define WATER 12
#define ADPROT 13
#define CAFFN 14
#define THEBRN 15
#define ENERC_KJ 16
#define SUGAR 17
#define GALS 18
#define FIBTG 19
#define CA 20
#define FE 21
#define MG 22
#define P 23
#define K 24
#define NA 25
#define ZN 26
#define CU 27
#define MN 28
#define SE 29
#define VITA_IU 30
#define RETOL 31
#define VITA_RAE 32
#define CARTB 33
#define CARTA 34
#define TOCPHA 35
#define VITD 36
#define CRYPX 37
#define LYCPN 38
#define LUT_ZEA 39
#define TOCPHB 40
#define TOCPHG 41
#define TOCPHD 42
#define VITC 43
#define THIA 44
#define RIBF 45
#define NIA 46
#define PANTAC 47
#define VITB6A 48
#define FOL 49
#define VITB12 50
#define VITK 51
#define FOLAC 52
#define FOLFD 53
#define FOLDFE 54
#define TRP_G 55
#define THR_G 56
#define ILE_G 57
#define LEU_G 58
#define LYS_G 59
#define MET_G 60
#define CYS_G 61
#define PHE_G 62
#define TYR_G 63
#define VAL_G 64
#define ARG_G 65
#define HISTN_G 66
#define ALA_G 67
#define ASP_G 68
#define GLU_G 69
#define GLY_G 70
#define PRO_G 71
#define SER_G 72
#define HYP 73
#define VITE_ADDED 74
#define VITB12_ADDED 75
#define CHOLE 76
#define FATRN 77
#define FASAT 78
#define F4D0 79
#define F6D0 80
#define F8D0 81
#define F10D0 82
#define F12D0 83
#define F14D0 84
#define F16D0 85
#define F18D0 86
#define F20D0 87
#define F18D1 88
#define F18D2 89
#define F18D3 90
#define F20D4 91
#define F22D6 92
#define F22D0 93
#define F14D1 94
#define F16D1 95
#define F18D4 96
#define F20D1 97
#define F20D5 98
#define F22D1 99
#define F22D5 100
#define PHYSTR 101
#define STID7 102
#define CAMD5 103
#define SITSTR 104
#define FAMS 105
#define FAPU 106
#define F15D0 107
#define F17D0 108
#define F24D0 109
#define F16D1T 110
#define F18D1T 111
#define F22D1T 112
#define F18D2T 113
#define F18D2I 114
#define F18D2TT 115
#define F18D2CLA 116
#define F24D1C 117
#define F20D2CN6 118
#define F16D1C 119
#define F18D1C 120
#define F18D2CN6 121
#define F22D1C 122
#define F18D3CN6 123
#define F17D1 124
#define F20D3 125
#define FATRNM 126
#define FATRNP 127
#define F13D0 128
#define F15D1 129
#define F18D3CN3 130
#define F20D3N6 131
#define F20D4N6 132
#define F18D3I 133
#define F21D5 134
#define F22D4 135
#define PROT_KCAL 136
#define FAT_KCAL 137
#define CHO_KCAL 138
#define CHO_NONFIB 139
#define LA 140
#define AA 141
#define ALA 142
#define EPA 143
#define DHA 144
#define OMEGA6 145
#define SHORT6 146
#define LONG6 147
#define OMEGA3 148
#define SHORT3 149
#define LONG3 150
#define VITE 151

#define NUTRIENT_COUNT 152
#define DERIVED 16
#define NUTRNO_ARRAYSIZE 859
